@@ -1,3 +1,4 @@
+
 /*
  Project: Graphos
  GRDocView.m
@@ -89,6 +90,7 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
     id obj;
     int i;
     int p = 0;
+    int c = 0;
     int t = 0;
     int b = 0;
 
@@ -106,8 +108,8 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
             b++;
         } else if([obj isKindOfClass: [GRCircle class]])
         {
-            str = [NSString stringWithFormat: @"circle%i", t];
-            t++;
+            str = [NSString stringWithFormat: @"circle%i", c];
+            c++;
         } else if([obj isKindOfClass: [GRText class]])
         {
             str = [NSString stringWithFormat: @"text%i", t];
@@ -295,6 +297,7 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
         [duplObj moveAddingCoordsOfPoint: p];
         [objects addObject: duplObj];
         [duplObjs addObject: duplObj];
+	[duplObj release];
     }
     edind = [objects count] -1;
     [self setNeedsDisplay: YES];
@@ -909,14 +912,11 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
 
 - (void)inspectObject:(id)sender
 {
-    NSWindow *epwin;
     GRPropsEditor *propsEditor;
-    unsigned int style = NSTitledWindowMask;
     NSMutableDictionary *objProps = nil;
     NSDictionary *newProps;
     id obj;
     NSNumber *num;
-    float *color, newcolor[4];
     int i, count, result;
     NSUndoManager *uMgr;
 
@@ -946,59 +946,19 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
                 [objProps setObject: num forKey: @"linewidth"];
                 num = [NSNumber numberWithInt: [obj isStroked]];
                 [objProps setObject: num forKey: @"stroked"];
-                color = [obj strokeColor];
-                num = [NSNumber numberWithFloat: color[0]];
-                [objProps setObject: num forKey: @"strokecyan"];
-                num = [NSNumber numberWithFloat: color[1]];
-                [objProps setObject: num forKey: @"strokemagenta"];
-                num = [NSNumber numberWithFloat: color[2]];
-                [objProps setObject: num forKey: @"strokeyellow"];
-                num = [NSNumber numberWithFloat: color[3]];
-                [objProps setObject: num forKey: @"strokeblack"];
-                num = [NSNumber numberWithFloat: [obj strokeAlpha]];
-                [objProps setObject: num forKey: @"strokealpha"];
-                num = [NSNumber numberWithInt: [obj isFilled]];
+                [objProps setObject: [obj strokeColor] forKey: @"strokecolor"];
+		num = [NSNumber numberWithInt: [obj isFilled]];
                 [objProps setObject: num forKey: @"filled"];
-                color = [obj fillColor];
-                num = [NSNumber numberWithFloat: color[0]];
-                [objProps setObject: num forKey: @"fillcyan"];
-                num = [NSNumber numberWithFloat: color[1]];
-                [objProps setObject: num forKey: @"fillmagenta"];
-                num = [NSNumber numberWithFloat: color[2]];
-                [objProps setObject: num forKey: @"fillyellow"];
-                num = [NSNumber numberWithFloat: color[3]];
-                [objProps setObject: num forKey: @"fillblack"];
-                num = [NSNumber numberWithFloat: [obj fillAlpha]];
-                [objProps setObject: num forKey: @"fillalpha"];
+                [objProps setObject: [obj fillColor] forKey: @"fillcolor"];
             } else
             {
                 [objProps setObject: @"text" forKey: @"type"];
                 num = [NSNumber numberWithInt: [obj isStroked]];
                 [objProps setObject: num forKey: @"stroked"];
-                color = [obj strokeColor];
-                num = [NSNumber numberWithFloat: color[0]];
-                [objProps setObject: num forKey: @"strokecyan"];
-                num = [NSNumber numberWithFloat: color[1]];
-                [objProps setObject: num forKey: @"strokemagenta"];
-                num = [NSNumber numberWithFloat: color[2]];
-                [objProps setObject: num forKey: @"strokeyellow"];
-                num = [NSNumber numberWithFloat: color[3]];
-                [objProps setObject: num forKey: @"strokeblack"];
-                num = [NSNumber numberWithFloat: [obj strokeAlpha]];
-                [objProps setObject: num forKey: @"strokealpha"];
-                num = [NSNumber numberWithInt: [obj isFilled]];
+                [objProps setObject: [obj strokeColor] forKey: @"strokecolor"];
+		num = [NSNumber numberWithInt: [obj isFilled]];
                 [objProps setObject: num forKey: @"filled"];
-                color = [obj fillColor];
-                num = [NSNumber numberWithFloat: color[0]];
-                [objProps setObject: num forKey: @"fillcyan"];
-                num = [NSNumber numberWithFloat: color[1]];
-                [objProps setObject: num forKey: @"fillmagenta"];
-                num = [NSNumber numberWithFloat: color[2]];
-                [objProps setObject: num forKey: @"fillyellow"];
-                num = [NSNumber numberWithFloat: color[3]];
-                [objProps setObject: num forKey: @"fillblack"];
-                num = [NSNumber numberWithFloat: [obj fillAlpha]];
-                [objProps setObject: num forKey: @"fillalpha"];
+                [objProps setObject: [obj fillColor] forKey: @"fillcolor"];
             }
             break;
         }
@@ -1006,17 +966,8 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
 
     if(!objProps)
         return;
-
-    epwin = [[NSPanel alloc] initWithContentRect: NSMakeRect(0, 0, 500, 305)
-                                        styleMask: style
-                                          backing: NSBackingStoreBuffered
-                                            defer: NO];
-    
-    [epwin setTitle: @"Object Properties"];
-    propsEditor = [[GRPropsEditor alloc] initWithFrame: NSMakeRect(0, 0, 500, 300)
-                                            forDocView: self objectProperties: objProps];
-    [epwin setContentView: propsEditor];
-    [epwin center];
+    propsEditor = [[GRPropsEditor alloc] initWithObjectProperties: objProps];
+//    [epwin center];
     result = [propsEditor runModal];
     if(result == NSAlertDefaultReturn)
     {
@@ -1030,7 +981,6 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
             result = NSRunAlertPanel(@"Alert", @"You are going to set the properties of many objects! Are you sure?", @"Ok", @"No", nil);
             if(result != NSAlertDefaultReturn)
             {
-                [epwin release];
                 return;
             }
         }
@@ -1048,6 +998,8 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
             obj = [objects objectAtIndex: i];
             if([[obj editor] isSelect])
             {
+	      NSColor *newColor;
+
                 if([obj isKindOfClass: [GRBezierPath class]] || [obj isKindOfClass: [GRBox class]] || [obj isKindOfClass: [GRCircle class]])
                 {
                     [obj setFlat: [[newProps objectForKey: @"flatness"] floatValue]];
@@ -1057,24 +1009,15 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
                     [obj setLineWidth: [[newProps objectForKey: @"linewidth"] floatValue]];
                 }
                 [obj setStroked: (BOOL)[[newProps objectForKey: @"stroked"] intValue]];
-                newcolor[0] = [[newProps objectForKey: @"strokecyan"] floatValue];
-                newcolor[1] = [[newProps objectForKey: @"strokemagenta"] floatValue];
-                newcolor[2] = [[newProps objectForKey: @"strokeyellow"] floatValue];
-                newcolor[3] = [[newProps objectForKey: @"strokeblack"] floatValue];
-                [obj setStrokeColor: newcolor];
-                [obj setStrokeAlpha: [[newProps objectForKey: @"strokealpha"] floatValue]];
+                newColor = (NSColor *)[newProps objectForKey: @"strokecolor"];
+                [obj setStrokeColor: newColor];
                 [obj setFilled: (BOOL)[[newProps objectForKey: @"filled"] intValue]];
-                newcolor[0] = [[newProps objectForKey: @"fillcyan"] floatValue];
-                newcolor[1] = [[newProps objectForKey: @"fillmagenta"] floatValue];
-                newcolor[2] = [[newProps objectForKey: @"fillyellow"] floatValue];
-                newcolor[3] = [[newProps objectForKey: @"fillblack"] floatValue];
-                [obj setFillColor: newcolor];
-                [obj setFillAlpha: [[newProps objectForKey: @"fillalpha"] floatValue]];
+                newColor = (NSColor *)[newProps objectForKey: @"fillcolor"];
+                [obj setFillColor: newColor];
             }
         }
     }
 
-    [epwin release];
     [self setNeedsDisplay: YES];
 }
 
@@ -1113,11 +1056,10 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
         {
             [objects removeObjectAtIndex: i];
             [objects insertObject: obj atIndex: i + 1];
-            [obj release];
             break;
         }
     }
-
+    [obj release];
     [self setNeedsDisplay: YES];
 }
 
@@ -1155,11 +1097,10 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
         {
             [objects removeObjectAtIndex: i];
             [objects insertObject: obj atIndex: i - 1];
-            [obj release];
             break;
         }
     }
-
+    [obj release];
     [self setNeedsDisplay: YES];
 }
 
